Traits for the Typhoon protocol.
This crate contains common traits used in the Typhoon ecosystem.
Structs
Traits
- Accessor
- Check
Owner - Trait to check whether a program ID is a valid owner.
- Check
Program Id - Trait to check whether a program ID matches an expected program.
- Data
Strategy - Discriminator
- Trait to define the unique discriminator for an account.
- MutAccessor
- Write